/*
** Module   : ImageButtonSupport.java
** Abstract : Defines image loading widget-related APIs available via a widget handle instance.
**
** Copyright (c) 2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 EVL 20150128 Created initial version.
*/

package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

/**
 * Provide access to image loading button-related APIs which can be accessed via handle instance.
 */
public interface ImageButtonSupport
extends ImageSupport
{
   /**
    * Load button image for normal state from specified file name.
    * 
    * @param   name
    *          Image file name.
    *          
    * @return  <code>true</code> if operation was successful.
    */
   @LegacyMethod(name = "LOAD-IMAGE-UP")
   public logical loadImageUp(String name);
   
   /**
    * Load button image for normal state from specified file name.
    * 
    * @param   name
    *          Image file name.
    *          
    * @return  <code>true</code> if operation was successful.
    */
   @LegacyMethod(name = "LOAD-IMAGE-UP")
   public logical loadImageUp(character name);
   
   /**
    * Load button image for pushed state from specified file name.
    * 
    * @param   name
    *          Image file name.
    *          
    * @return  <code>true</code> if operation was successful.
    */
   @LegacyMethod(name = "LOAD-IMAGE-DOWN")
   public logical loadImageDown(String name);
   
   /**
    * Load button image for pushed state from specified file name.
    * 
    * @param   name
    *          Image file name.
    *          
    * @return  <code>true</code> if operation was successful.
    */
   @LegacyMethod(name = "LOAD-IMAGE-DOWN")
   public logical loadImageDown(character name);
   
   /**
    * Load button image for disabled state from specified file name.
    * 
    * @param   name
    *          Image file name.
    *          
    * @return  <code>true</code> if operation was successful.
    */
   @LegacyMethod(name = "LOAD-IMAGE-INSENSITIVE")
   public logical loadImageInsensitive(String name);
   
   /**
    * Load button image for disabled state from specified file name.
    * 
    * @param   name
    *          Image file name.
    *          
    * @return  <code>true</code> if operation was successful.
    */
   @LegacyMethod(name = "LOAD-IMAGE-INSENSITIVE")
   public logical loadImageInsensitive(character name);
}
